"""
NeuraTensor Config Module
=========================

Configuration management for NeuraTensor models.
"""

from .model_config import ModelConfig, JetsonOrinConfig

__all__ = ['ModelConfig', 'JetsonOrinConfig']
